/**
 * 判断url是否是http或https
 * @param {string} path
 * @returns {Boolean}
 */
export function isHttp(url: string) {
  return url.indexOf("http://") !== -1 || url.indexOf("https://") !== -1;
}

/**
 * 判断path是否为外链
 * @param {string} path
 * @returns {Boolean}
 */
export function isExternal(path: string) {
  return /^(https?:|mailto:|tel:)/.test(path);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validUsername(str: string) {
  const valid_map = ["admin", "editor"];
  return valid_map.indexOf(str.trim()) >= 0;
}

/**
 * @param {string} url
 * @returns {Boolean}
 */
export function validURL(url: string) {
  const reg =
    /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/;
  return reg.test(url);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validLowerCase(str: string) {
  const reg = /^[a-z]+$/;
  return reg.test(str);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validUpperCase(str: string) {
  const reg = /^[A-Z]+$/;
  return reg.test(str);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function validAlphabets(str: string) {
  const reg = /^[A-Za-z]+$/;
  return reg.test(str);
}

/**
 * @param {string} email
 * @returns {Boolean}
 */
export function validEmail(email: string) {
  const reg =
    /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
  return reg.test(email);
}

/**
 * @param {string} str
 * @returns {Boolean}
 */
export function isString(str: string) {
  if (typeof str === "string") {
    return true;
  }
  return false;
}

/**
 * @param {Array} arg
 * @returns {Boolean}
 */
export function isArray(arg: string) {
  if (typeof Array.isArray === "undefined") {
    return Object.prototype.toString.call(arg) === "[object Array]";
  }
  return Array.isArray(arg);
}

/**
 * 获取据今天前几天或后几天的日期 年月日
 * @param {Object} coun
 */
export const getGivenTime = (count: number) => {
  var date = new Date();
  date.setDate(date.getDate() + count);
  return date.getFullYear() + "-" + (date.getMonth() + 1) + "-" + date.getDate();
};

/**
 * 本月第一天
 * @param e 日期
 */
export const getFirstDay = () => {
  let y = new Date().getFullYear(); //获取年份
  let m = new Date().getMonth() + 1; //获取月份
  let d = "01";
  let _m = m < 10 ? "0" + m : m; //月份补 0
  return [y, _m, d].join("-");
};

/**
 * 本月最后一天
 * @param e 指定年月
 */
export const getLastDay = (e: string) => {
  let str = "";
  if (e) {
    var y = new Date(e).getFullYear(); //获取年份
    var m = new Date(e).getMonth() + 1; //获取月份
    var d = new Date(y, m, 0).getDate(); //获取当月最后一日
    let _m = m < 10 ? "0" + m : m; //月份补 0
    let _d = d < 10 ? "0" + d : d; //日数补 0
    str = [y, _m, _d].join("-");
  } else {
    var y = new Date().getFullYear(); //获取年份
    var m = new Date().getMonth() + 1; //获取月份
    var d = new Date(y, m, 0).getDate(); //获取当月最后一日
    let _m = m < 10 ? "0" + m : m; //月份补 0
    let _d = d < 10 ? "0" + d : d; //日数补 0
    str = [y, _m, _d].join("-");
  }
  return str;
};

/**
 * 获取当前年月日
 * @param spt
 * @returns
 */
export const getTodayDate = (spt = "-") => {
  let date = new Date();
  let year = date.getFullYear();
  let month = date.getMonth() + 1;
  let _month = month < 10 ? "0" + month : month;
  let day = date.getDate();
  let _day = day < 10 ? "0" + day : day;
  return year + spt + _month + spt + _day;
};
